@@ -623,7 +623,7 @@ class IPobject(unittest.TestCase):
         self.failUnlessEqual(IPy.IP("255.255.255.255").int(), 0xffffffffL)
         self.failUnlessEqual(IPy.IP("0000:0000:0000:0000:0000:0000:0000:0000").int(), 0)
         self.failUnlessEqual(IPy.IP("ffff:ffff:ffff:ffff:ffff:ffff:ffff:ffff").int(), 0xffffffffffffffffffffffffffffffffL)
-        self.failUnlessEqual(IPy.IP("2001:1234:5678:9abc:de00:0000:0000:0000").int(), 42540857391974671903776007410583339008)
+        self.failUnlessEqual(IPy.IP("2001:1234:5678:9abc:de00:0000:0000:0000").int(), 42540857391974671903776007410583339008L)
     
 
     def testPrefixlen(self):
@@ -713,7 +713,7 @@ class NetIPChecks(unittest.TestCase):
         
         ip = IPy.IP('dead:beef:0::/48')
         self.assertEqual(str(ip.net()),'dead:beef:0000:0000:0000:0000:0000:0000')
-        self.assertEqual(ip.int(), 295990755014133383690938178081940045824)
+        self.assertEqual(ip.int(), 295990755014133383690938178081940045824L)
         self.assertEqual(ip.strBin(),'11011110101011011011111011101111000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000')
         self.assertEqual(ip.strCompressed(),'dead:beef::/48')
         self.assertEqual(ip.prefixlen(), 48)
